==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/KubernetesClusterBackupDatasourceParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for Kubernetes Cluster Backup Datasource
 * @property excludedNamespaces Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
 * @property excludedResourceTypes Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
 * @property includeClusterScopeResources Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
 * @property includedNamespaces Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
 * @property includedResourceTypes Gets or sets the include resource types property. This property sets the resource types to be included during restore.
 * @property labelSelectors Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
 * @property snapshotVolumes Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
 */
public data class KubernetesClusterBackupDatasourceParametersArgs(
    public val excludedNamespaces: Output<List<String>>? = null,
    public val excludedResourceTypes: Output<List<String>>? = null,
    public val includeClusterScopeResources: Output<Boolean>,
    public val includedNamespaces: Output<List<String>>? = null,
    public val includedResourceTypes: Output<List<String>>? = null,
    public val labelSelectors: Output<List<String>>? = null,
    public val objectType: Output<String>,
    public val snapshotVolumes: Output<Boolean>,
) :
    ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs.builder()
            .excludedNamespaces(excludedNamespaces?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .excludedResourceTypes(excludedResourceTypes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includeClusterScopeResources(includeClusterScopeResources.applyValue({ args0 -> args0 }))
            .includedNamespaces(includedNamespaces?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedResourceTypes(includedResourceTypes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .labelSelectors(labelSelectors?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .objectType(objectType.applyValue({ args0 -> args0 }))
            .snapshotVolumes(snapshotVolumes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KubernetesClusterBackupDatasourceParametersArgs].
 */
@PulumiTagMarker
public class KubernetesClusterBackupDatasourceParametersArgsBuilder internal constructor() {
    private var excludedNamespaces: Output<List<String>>? = null

    private var excludedResourceTypes: Output<List<String>>? = null

    private var includeClusterScopeResources: Output<Boolean>? = null

    private var includedNamespaces: Output<List<String>>? = null

    private var includedResourceTypes: Output<List<String>>? = null

    private var labelSelectors: Output<List<String>>? = null

    private var objectType: Output<String>? = null

    private var snapshotVolumes: Output<Boolean>? = null

    /**
     * @param value Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("dlbuajsexjkjipot")
    public suspend fun excludedNamespaces(`value`: Output<List<String>>) {
        this.excludedNamespaces = value
    }

    @JvmName("kuustdsqpojqsand")
    public suspend fun excludedNamespaces(vararg values: Output<String>) {
        this.excludedNamespaces = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("ifprphrrrfcmuiiv")
    public suspend fun excludedNamespaces(values: List<Output<String>>) {
        this.excludedNamespaces = Output.all(values)
    }

    /**
     * @param value Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("tdygydtkoekfhxnj")
    public suspend fun excludedResourceTypes(`value`: Output<List<String>>) {
        this.excludedResourceTypes = value
    }

    @JvmName("gycconveosfyxgve")
    public suspend fun excludedResourceTypes(vararg values: Output<String>) {
        this.excludedResourceTypes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("eipmabgtbhmcnuve")
    public suspend fun excludedResourceTypes(values: List<Output<String>>) {
        this.excludedResourceTypes = Output.all(values)
    }

    /**
     * @param value Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
     */
    @JvmName("yhcaelkpktxyqbnr")
    public suspend fun includeClusterScopeResources(`value`: Output<Boolean>) {
        this.includeClusterScopeResources = value
    }

    /**
     * @param value Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("peoatiiomtpfpptd")
    public suspend fun includedNamespaces(`value`: Output<List<String>>) {
        this.includedNamespaces = value
    }

    @JvmName("phigcvwrxeiwdppu")
    public suspend fun includedNamespaces(vararg values: Output<String>) {
        this.includedNamespaces = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("rmxldnqvbnmpguhu")
    public suspend fun includedNamespaces(values: List<Output<String>>) {
        this.includedNamespaces = Output.all(values)
    }

    /**
     * @param value Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("jonjnocyvxqaikab")
    public suspend fun includedResourceTypes(`value`: Output<List<String>>) {
        this.includedResourceTypes = value
    }

    @JvmName("gtahmmcnmyreiuuh")
    public suspend fun includedResourceTypes(vararg values: Output<String>) {
        this.includedResourceTypes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("gcexacagmxrloysu")
    public suspend fun includedResourceTypes(values: List<Output<String>>) {
        this.includedResourceTypes = Output.all(values)
    }

    /**
     * @param value Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("gsrdabknpnxrfipp")
    public suspend fun labelSelectors(`value`: Output<List<String>>) {
        this.labelSelectors = value
    }

    @JvmName("whrravtvikbragvs")
    public suspend fun labelSelectors(vararg values: Output<String>) {
        this.labelSelectors = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("dlabqkkiwgoquevi")
    public suspend fun labelSelectors(values: List<Output<String>>) {
        this.labelSelectors = Output.all(values)
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
     */
    @JvmName("wlcgglurhrdsvtax")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
     */
    @JvmName("yjoafshdfjjtsutm")
    public suspend fun snapshotVolumes(`value`: Output<Boolean>) {
        this.snapshotVolumes = value
    }

    /**
     * @param value Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("whlmpxggtdieqjaw")
    public suspend fun excludedNamespaces(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedNamespaces = mapped
    }

    /**
     * @param values Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("htlxlhpdwtyqupgh")
    public suspend fun excludedNamespaces(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedNamespaces = mapped
    }

    /**
     * @param value Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("rgrdjeilmbaqyikk")
    public suspend fun excludedResourceTypes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedResourceTypes = mapped
    }

    /**
     * @param values Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("drdorpgpnpjqqdys")
    public suspend fun excludedResourceTypes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedResourceTypes = mapped
    }

    /**
     * @param value Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
     */
    @JvmName("psxuihvaehahjkdy")
    public suspend fun includeClusterScopeResources(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includeClusterScopeResources = mapped
    }

    /**
     * @param value Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("hdymtbvefrjosguu")
    public suspend fun includedNamespaces(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedNamespaces = mapped
    }

    /**
     * @param values Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("vtdkkuemhukkeaqt")
    public suspend fun includedNamespaces(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedNamespaces = mapped
    }

    /**
     * @param value Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("jjfbxvdvqqayosuj")
    public suspend fun includedResourceTypes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedResourceTypes = mapped
    }

    /**
     * @param values Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("vgxkxmlecouxgedh")
    public suspend fun includedResourceTypes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedResourceTypes = mapped
    }

    /**
     * @param value Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("uqgfbbdxproqxeog")
    public suspend fun labelSelectors(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelSelectors = mapped
    }

    /**
     * @param values Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("vwfwrdrhbamsujrm")
    public suspend fun labelSelectors(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.labelSelectors = mapped
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
     */
    @JvmName("heboewodnhnkdycf")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
     */
    @JvmName("pfvrjsphyvmssner")
    public suspend fun snapshotVolumes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.snapshotVolumes = mapped
    }

    internal fun build(): KubernetesClusterBackupDatasourceParametersArgs =
        KubernetesClusterBackupDatasourceParametersArgs(
            excludedNamespaces = excludedNamespaces,
            excludedResourceTypes = excludedResourceTypes,
            includeClusterScopeResources = includeClusterScopeResources ?: throw
                PulumiNullFieldException("includeClusterScopeResources"),
            includedNamespaces = includedNamespaces,
            includedResourceTypes = includedResourceTypes,
            labelSelectors = labelSelectors,
            objectType = objectType ?: throw PulumiNullFieldException("objectType"),
            snapshotVolumes = snapshotVolumes ?: throw PulumiNullFieldException("snapshotVolumes"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/KubernetesClusterBackupDatasourceParametersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for Kubernetes Cluster Backup Datasource
 * @property excludedNamespaces Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
 * @property excludedResourceTypes Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
 * @property includeClusterScopeResources Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
 * @property includedNamespaces Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
 * @property includedResourceTypes Gets or sets the include resource types property. This property sets the resource types to be included during restore.
 * @property labelSelectors Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
 * @property objectType Type of the specific object - used for deserializing
 * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
 * @property snapshotVolumes Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
 */
public data class KubernetesClusterBackupDatasourceParametersArgs(
    public val excludedNamespaces: Output<List<String>>? = null,
    public val excludedResourceTypes: Output<List<String>>? = null,
    public val includeClusterScopeResources: Output<Boolean>,
    public val includedNamespaces: Output<List<String>>? = null,
    public val includedResourceTypes: Output<List<String>>? = null,
    public val labelSelectors: Output<List<String>>? = null,
    public val objectType: Output<String>,
    public val snapshotVolumes: Output<Boolean>,
) :
    ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs> {
    override fun toJava():
        com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs =
        com.pulumi.azurenative.dataprotection.inputs.KubernetesClusterBackupDatasourceParametersArgs.builder()
            .excludedNamespaces(excludedNamespaces?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .excludedResourceTypes(excludedResourceTypes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includeClusterScopeResources(includeClusterScopeResources.applyValue({ args0 -> args0 }))
            .includedNamespaces(includedNamespaces?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedResourceTypes(includedResourceTypes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .labelSelectors(labelSelectors?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .objectType(objectType.applyValue({ args0 -> args0 }))
            .snapshotVolumes(snapshotVolumes.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [KubernetesClusterBackupDatasourceParametersArgs].
 */
@PulumiTagMarker
public class KubernetesClusterBackupDatasourceParametersArgsBuilder internal constructor() {
    private var excludedNamespaces: Output<List<String>>? = null

    private var excludedResourceTypes: Output<List<String>>? = null

    private var includeClusterScopeResources: Output<Boolean>? = null

    private var includedNamespaces: Output<List<String>>? = null

    private var includedResourceTypes: Output<List<String>>? = null

    private var labelSelectors: Output<List<String>>? = null

    private var objectType: Output<String>? = null

    private var snapshotVolumes: Output<Boolean>? = null

    /**
     * @param value Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("vlamdodfdkdkbdwr")
    public suspend fun excludedNamespaces(`value`: Output<List<String>>) {
        this.excludedNamespaces = value
    }

    @JvmName("tnhxojkgfbuefflv")
    public suspend fun excludedNamespaces(vararg values: Output<String>) {
        this.excludedNamespaces = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("whjntmqcixyvfery")
    public suspend fun excludedNamespaces(values: List<Output<String>>) {
        this.excludedNamespaces = Output.all(values)
    }

    /**
     * @param value Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("lpmwstjxrvyngged")
    public suspend fun excludedResourceTypes(`value`: Output<List<String>>) {
        this.excludedResourceTypes = value
    }

    @JvmName("cdedppjbkxndqyfu")
    public suspend fun excludedResourceTypes(vararg values: Output<String>) {
        this.excludedResourceTypes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("vgyhvblikaisgias")
    public suspend fun excludedResourceTypes(values: List<Output<String>>) {
        this.excludedResourceTypes = Output.all(values)
    }

    /**
     * @param value Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
     */
    @JvmName("vldjsdwlwydpinsn")
    public suspend fun includeClusterScopeResources(`value`: Output<Boolean>) {
        this.includeClusterScopeResources = value
    }

    /**
     * @param value Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("gupfqgsxcpcqgoww")
    public suspend fun includedNamespaces(`value`: Output<List<String>>) {
        this.includedNamespaces = value
    }

    @JvmName("nmaxjnoajokplnxc")
    public suspend fun includedNamespaces(vararg values: Output<String>) {
        this.includedNamespaces = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("gtnioekmjrjtwcph")
    public suspend fun includedNamespaces(values: List<Output<String>>) {
        this.includedNamespaces = Output.all(values)
    }

    /**
     * @param value Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("brljfbvewktsikli")
    public suspend fun includedResourceTypes(`value`: Output<List<String>>) {
        this.includedResourceTypes = value
    }

    @JvmName("oecphdxkyranckpj")
    public suspend fun includedResourceTypes(vararg values: Output<String>) {
        this.includedResourceTypes = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("rnmghshnyhlcldao")
    public suspend fun includedResourceTypes(values: List<Output<String>>) {
        this.includedResourceTypes = Output.all(values)
    }

    /**
     * @param value Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("upebtwurnoskekdw")
    public suspend fun labelSelectors(`value`: Output<List<String>>) {
        this.labelSelectors = value
    }

    @JvmName("mifmcrxroouchfjf")
    public suspend fun labelSelectors(vararg values: Output<String>) {
        this.labelSelectors = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("nmedngxbaagntsqb")
    public suspend fun labelSelectors(values: List<Output<String>>) {
        this.labelSelectors = Output.all(values)
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
     */
    @JvmName("pcnucqrhmftqspyv")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
     */
    @JvmName("irjtrrifcedvwras")
    public suspend fun snapshotVolumes(`value`: Output<Boolean>) {
        this.snapshotVolumes = value
    }

    /**
     * @param value Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("knxokldyihfefpxi")
    public suspend fun excludedNamespaces(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedNamespaces = mapped
    }

    /**
     * @param values Gets or sets the exclude namespaces property. This property sets the namespaces to be excluded during restore.
     */
    @JvmName("gumyclihwdickjjy")
    public suspend fun excludedNamespaces(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedNamespaces = mapped
    }

    /**
     * @param value Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("wnbtiiacqrtdeoup")
    public suspend fun excludedResourceTypes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedResourceTypes = mapped
    }

    /**
     * @param values Gets or sets the exclude resource types property. This property sets the resource types to be excluded during restore.
     */
    @JvmName("qvwvhoncvqtcuiej")
    public suspend fun excludedResourceTypes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedResourceTypes = mapped
    }

    /**
     * @param value Gets or sets the include cluster resources property. This property if enabled will include cluster scope resources during restore.
     */
    @JvmName("elrpnufbbeaovwtv")
    public suspend fun includeClusterScopeResources(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includeClusterScopeResources = mapped
    }

    /**
     * @param value Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("dvtvbasngbvmyjyj")
    public suspend fun includedNamespaces(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedNamespaces = mapped
    }

    /**
     * @param values Gets or sets the include namespaces property. This property sets the namespaces to be included during restore.
     */
    @JvmName("hxbclawhdkcxfspk")
    public suspend fun includedNamespaces(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedNamespaces = mapped
    }

    /**
     * @param value Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("grrwdipellmvaeqo")
    public suspend fun includedResourceTypes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedResourceTypes = mapped
    }

    /**
     * @param values Gets or sets the include resource types property. This property sets the resource types to be included during restore.
     */
    @JvmName("oqklhffbrsailhts")
    public suspend fun includedResourceTypes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedResourceTypes = mapped
    }

    /**
     * @param value Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("ajfnethkpyrwtmww")
    public suspend fun labelSelectors(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.labelSelectors = mapped
    }

    /**
     * @param values Gets or sets the LabelSelectors property. This property sets the resource with such label selectors to be included during restore.
     */
    @JvmName("maigdpidkityxcaf")
    public suspend fun labelSelectors(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.labelSelectors = mapped
    }

    /**
     * @param value Type of the specific object - used for deserializing
     * Expected value is 'KubernetesClusterBackupDatasourceParameters'.
     */
    @JvmName("tfjqyqjrjwwpjsyp")
    public suspend fun objectType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value Gets or sets the volume snapshot property. This property if enabled will take volume snapshots during restore.
     */
    @JvmName("pakomxivjsnipbcj")
    public suspend fun snapshotVolumes(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.snapshotVolumes = mapped
    }

    internal fun build(): KubernetesClusterBackupDatasourceParametersArgs =
        KubernetesClusterBackupDatasourceParametersArgs(
            excludedNamespaces = excludedNamespaces,
            excludedResourceTypes = excludedResourceTypes,
            includeClusterScopeResources = includeClusterScopeResources ?: throw
                PulumiNullFieldException("includeClusterScopeResources"),
            includedNamespaces = includedNamespaces,
            includedResourceTypes = includedResourceTypes,
            labelSelectors = labelSelectors,
            objectType = objectType ?: throw PulumiNullFieldException("objectType"),
            snapshotVolumes = snapshotVolumes ?: throw PulumiNullFieldException("snapshotVolumes"),
        )
}
